/*
 * Copyright (C) 2019-2024 CZ.NIC z.s.p.o. (https://www.nic.cz/)
 *
 * This is free software, licensed under the GNU General Public License v3.
 * See /LICENSE for more information.
 */

import React from "react";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import {
    faSquareCaretUp,
    faSquareCaretDown,
} from "@fortawesome/free-solid-svg-icons";

const RichTableHeader = ({ table, flexRender }) => {
    const getThTitle = (header) =>
        header.column.getCanSort()
            ? header.column.getNextSortingOrder() === "asc"
                ? _("Sort ascending")
                : header.column.getNextSortingOrder() === "desc"
                  ? _("Sort descending")
                  : _("Clear sort")
            : undefined;

    return (
        <thead className="thead-light">
            {table.getHeaderGroups().map((headerGroup) => (
                <tr key={headerGroup.id}>
                    {headerGroup.headers.map((header) => {
                        return (
                            <th key={header.id} colSpan={header.colSpan}>
                                {header.isPlaceholder ? null : (
                                    <button
                                        className={`btn btn-link text-decoration-none text-reset fw-bold p-0 d-flex align-items-center
                                                    ${
                                                        header.column.getCanSort()
                                                            ? "d-flex align-items-center"
                                                            : ""
                                                    }
                                                `}
                                        onClick={header.column.getToggleSortingHandler()}
                                        title={getThTitle(header)}
                                    >
                                        {flexRender(
                                            header.column.columnDef.header,
                                            header.getContext()
                                        )}
                                        {{
                                            asc: (
                                                <FontAwesomeIcon
                                                    icon={faSquareCaretUp}
                                                    className="ms-1 text-primary"
                                                />
                                            ),
                                            desc: (
                                                <FontAwesomeIcon
                                                    icon={faSquareCaretDown}
                                                    className="ms-1 text-primary"
                                                />
                                            ),
                                        }[header.column.getIsSorted()] ?? null}
                                    </button>
                                )}
                            </th>
                        );
                    })}
                </tr>
            ))}
        </thead>
    );
};

export default RichTableHeader;
